==> gulp-rb-validate-header-0.0.7.tgz: package/index.js <==
/*jslint node: true */
'use strict';

var meta = require('./package.json'),
    gutil = require('gulp-util'),
    through = require('through2'),
    fs = require('fs'),
    error = false,
    errorBreak = false,
    guideline = 'CI-FE-1001',
    errorTitle = 'Copyright Header';


/** 
 * Validation Error Printout
 * abort = true => breaks build if flag is set
 */
function validationError(tag, mistake, guideline, abort) {

    error = true;

    if (abort) {
        gutil.log('[' + guideline + '] ' + gutil.colors.white(tag + ": ") + gutil.colors.red(mistake) + " [Level Red]");
        errorBreak = true;
    } else {
        gutil.log('[' + guideline + '] ' + gutil.colors.white(tag + ": ") + gutil.colors.yellow(mistake) + " [Level Orange]");
    }
}

/**
 * Rules:
 * One line per information: Summary, Author, Date, Copyright, 
 * No empty values
 */
function infoOk(info, lines, list) {

    var ok = false;
    var next = false;

    lines.some(function (line) {
        if (line.includes(info)) {

            next = false;

            line = line.replace(/\s\s+/g, '');

            if ((line.length - info.length) >= 2) {
                ok = true;
            } else {
                next = true;
            }
        } else if (next && line.substr(line.search(/\S|$/)) !== '') {

            next = false;

            // Check if this is another field already
            var other = false;

            list.forEach(function (s) {
                if (line.includes(s)) {
                    other = true;
                }
            });

            if (!other) {
                ok = true;
            }
        }
    });
    return ok;
}

function checkTitle(lines, infos) {

    var found = false;
    var other = false;

    lines.forEach(function (line) {

        if (!found && !other) {

            infos.forEach(function (s) {
                if (line.includes(s)) {
                    other = true;
                }
            });

            if (!other) {

                var check = line.replace(/\s/g, '').replace(/\*/g, '');

                if (check.length > 0) {
                    found = true;
                }
            }
        }
    });

    if (!found) {
        validationError(errorTitle, 'No title found in copyright header', guideline, true);
    }
}

function checkHeader(comment) {

    if (comment.substr(comment.search(/\S|$/)) !== '') {

        var lines = comment.split(/\r?\n/),
            infos = ["Summary", "Author", "Date", "Copyright"];

        infos.some(function (info) {
            if (!infoOk(info, lines, infos)) {
                validationError(errorTitle, '"' + info + '" does not exist or is empty', guideline, true);
            } else if (info === 'Copyright') {
                if (comment.indexOf('Robert Bosch GmbH') <= 0) {
                    validationError(errorTitle, 'Copyright value "Robert Bosch GmbH" is missing or incorrect', guideline, true);
                }
            }
        });
        checkTitle(lines, infos);

    } else {
        validationError(errorTitle, 'No Copyright Header found (Declare partials by starting the filename with "_")', guideline, true);
    }
}

module.exports = function validate(options) {

    if (!options) {
        options = {};
    }

    var errorOutputList = [];

    function transformFunction(file, encoding, callback) {

        var filename = file.path.replace(/^.*[\\\/]/, '');

        if (filename.charAt(0) !== '_') {

            fs.readFile(file.path, 'utf8', function (err, str) {

                error = false;

                if (!str) {
                    validationError('', 'File is empty or null', 'WARNING', false);
                } else {
                    var comment = (str.substr(str.indexOf("/*") + 2, (str.indexOf("*/") - str.indexOf("/*") - 2)));

                    checkHeader(comment);

                    if (error) {
                        if (comment.substr(comment.search(/\S|$/)) !== '') {
                            gutil.log(gutil.colors.red(comment));
                        }
                    }
                }

                if (error) {
                    gutil.log(gutil.colors.cyan(file.path));
                    if (options.exitOnError && errorBreak) {
                        gutil.log(gutil.colors.red("Critical validation error -> EXIT") + " (exitOnError is active)");
                        process.exit(1);
                    }
                    gutil.log();

                }

            });
        }

        return callback(null, file);
    }

    function errorOutput(callback) {
        if (errorOutputList.length > 0) {
            this.emit('error', new gutil.PluginError(meta.name, '\n' + errorOutputList.join('\n\n') + '\n', {
                showStack: false
            }));
        }
        callback();
    }

    return through.obj(transformFunction, errorOutput);
};

==> gulp-rb-validate-header-0.0.9.tgz: package/index.js <==
/*jslint node: true */
'use strict';

var meta = require('./package.json'),
    gutil = require('gulp-util'),
    through = require('through2'),
    fs = require('fs'),
    error = false,
    errorBreak = false,
    guideline = 'CI-FE-1001',
    errorTitle = 'Copyright Header';

// Polyfill
if (!String.prototype.includes) {
  String.prototype.includes = function(search, start) {
    'use strict';
    if (typeof start !== 'number') {
      start = 0;
    }
    
    if (start + search.length > this.length) {
      return false;
    } else {
      return this.indexOf(search, start) !== -1;
    }
  };
}

/** 
 * Validation Error Printout
 * abort = true => breaks build if flag is set
 */
function validationError(tag, mistake, guideline, abort) {

    error = true;

    if (abort) {
        gutil.log('[' + guideline + '] ' + gutil.colors.white(tag + ": ") + gutil.colors.red(mistake) + " [Level Red]");
        errorBreak = true;
    } else {
        gutil.log('[' + guideline + '] ' + gutil.colors.white(tag + ": ") + gutil.colors.yellow(mistake) + " [Level Orange]");
    }
}

/**
 * Rules:
 * One line per information: Summary, Author, Date, Copyright, 
 * No empty values
 */
function infoOk(info, lines, list) {

    var ok = false;
    var next = false;

    lines.some(function (line) {
        if (line.includes(info + ":")) {

            next = false;

            line = line.replace(/\s\s+/g, '');

            if ((line.length - info.length) >= 2) {
                ok = true;
            } else {
                next = true;
            }
        } else if (next && line.substr(line.search(/\S|$/)) !== '') {

            next = false;

            // Check if this is another field already
            var other = false;

            list.forEach(function (s) {
                if (line.includes(s)) {
                    other = true;
                }
            });

            if (!other) {
                ok = true;
            }
        }
    });
    return ok;
}

function checkTitle(lines, infos) {

    var found = false;
    var other = false;

    lines.forEach(function (line) {

        if (!found && !other) {

            infos.forEach(function (s) {
                if (line.includes(s + ":")) {
                    other = true;
                }
            });

            if (!other) {

                var check = line.replace(/\s/g, '').replace(/\*/g, '');

                if (check.length > 0) {
                    found = true;
                }
            }
        }
    });

    if (!found) {
        validationError(errorTitle, 'No title found in copyright header', guideline, true);
    }
}

function checkHeader(comment) {

    if (comment.substr(comment.search(/\S|$/)) !== '') {

        var lines = comment.split(/\r?\n/),
            infos = ["Summary", "Author", "Date", "Copyright"];

        infos.some(function (info) {
            if (!infoOk(info, lines, infos)) {
                validationError(errorTitle, '"' + info + '" does not exist or is empty', guideline, true);
            } else if (info === 'Copyright') {
                if (comment.indexOf('Robert Bosch GmbH') <= 0) {
                    validationError(errorTitle, 'Copyright value "Robert Bosch GmbH" is missing or incorrect', guideline, true);
                }
            }
        });
        checkTitle(lines, infos);

    } else {
        validationError(errorTitle, 'No Copyright Header found (Declare partials by starting the filename with "_")', guideline, true);
    }
}

module.exports = function validate(options) {

    if (!options) {
        options = {};
    }

    var errorOutputList = [];

    function transformFunction(file, encoding, callback) {

        var filename = file.path.replace(/^.*[\\\/]/, '');

        if (filename.charAt(0) !== '_') {
            
            fs.readFile(file.path, 'utf8', function (err, str) {

                error = false;

                if (!str) {
                    validationError('', 'File is empty or null', 'CI-FE-WARNING', false);
                } else {
                    var comment = (str.substr(str.indexOf("/*") + 2, (str.indexOf("*/") - str.indexOf("/*") - 2)));

                    checkHeader(comment);

                    if (error) {
                        if (comment.substr(comment.search(/\S|$/)) !== '') {
                            gutil.log(gutil.colors.red('/*' + comment + '*/'));
                        }
                    }
                }

                if (error) {
                    gutil.log(gutil.colors.cyan("File: " + file.path));
                    if (options.exitOnError && errorBreak) {
                        gutil.log(gutil.colors.red("Critical validation error -> EXIT") + " (exitOnError is active)");
                        process.exit(1);
                    }
                    gutil.log();

                }

            });
        }

        return callback(null, file);
    }

    function errorOutput(callback) {
        if (errorOutputList.length > 0) {
            this.emit('error', new gutil.PluginError(meta.name, '\n' + errorOutputList.join('\n\n') + '\n', {
                showStack: false
            }));
        }
        callback();
    }

    return through.obj(transformFunction, errorOutput);
};
